@@ -33,6 +33,10 @@
 #include <linphonecore.h>
 #include "linphonec.h"
 
+#ifndef WIN32
+#include <sys/wait.h>
+#endif
+
 /***************************************************************************
  *
  *  Forward declarations 
@@ -64,6 +68,7 @@ static int lpc_cmd_unregister(LinphoneCore *, char *);
 static int lpc_cmd_duration(LinphoneCore *lc, char *args);
 static int lpc_cmd_status(LinphoneCore *lc, char *args);
 static int lpc_cmd_ports(LinphoneCore *lc, char *args);
+static int lpc_cmd_speak(LinphoneCore *lc, char *args);
 
 /* Command handler helpers */
 static void linphonec_proxy_add(LinphoneCore *lc);
@@ -76,7 +81,9 @@ static void linphonec_friend_display(LinphoneFriend *fr);
 static int linphonec_friend_list(LinphoneCore *lc, char *arg);
 static void linphonec_display_command_help(LPC_COMMAND *cmd);
 static int linphonec_friend_call(LinphoneCore *lc, unsigned int num);
+#ifndef WIN32
 static int linphonec_friend_add(LinphoneCore *lc, const char *name, const char *addr);
+#endif
 static int linphonec_friend_delete(LinphoneCore *lc, int num);
 
 
@@ -179,6 +186,11 @@ LPC_COMMAND commands[] = {
 	{ "ports", lpc_cmd_ports, "Network ports configuration", 
 			"'ports'  \t: prints current used ports.\n"
 			"'ports sip <port number>'\t: Sets the sip port.\n" },
+	{ "speak", lpc_cmd_speak, "Speak a sentence using espeak TTS engine",
+			"This feature is available only in file mode. (see 'help soundcard')\n"
+			"'speak <voice name> <sentence>'	: speak a text using the specified espeak voice.\n"
+			"Example for english voice: 'speak default Hello my friend !'"
+	},
 	{ (char *)NULL, (lpc_cmd_handler)NULL, (char *)NULL, (char *)NULL }
 };
 
@@ -321,6 +333,7 @@ lpc_cmd_help(LinphoneCore *lc, char *arg)
 }
 
 static char callee_name[256]={0};
+static char caller_name[256]={0};
 
 static int
 lpc_cmd_call(LinphoneCore *lc, char *args)
@@ -348,10 +361,18 @@ lpc_cmd_call(LinphoneCore *lc, char *args)
 	return 1;
 }
 
-static const char *linphonec_get_callee(){
+const char *linphonec_get_callee(){
 	return callee_name;
 }
 
+const char *linphonec_get_caller(){
+	return caller_name;
+}
+
+void linphonec_set_caller(const char *caller){
+	snprintf(caller_name,sizeof(caller_name)-1,"%s",caller);
+}
+
 static int
 lpc_cmd_refer(LinphoneCore *lc, char *args)
 {
@@ -398,10 +419,10 @@ lpc_cmd_autoanswer(LinphoneCore *lc, char *args)
 
 	if (strstr(args,"enable")){
 		linphonec_set_autoanswer(TRUE);
-		linphonec_out("Auto answer disabled.\n");
+		linphonec_out("Auto answer enabled.\n");
 	}else if (strstr(args,"disable")){
 		linphonec_set_autoanswer(FALSE);
-		linphonec_out("Auto answer enabled.\n");
+		linphonec_out("Auto answer disabled.\n");
 	}else return 0;
 	return 1;
 }
@@ -409,7 +430,7 @@ lpc_cmd_autoanswer(LinphoneCore *lc, char *args)
 static int
 lpc_cmd_quit(LinphoneCore *lc, char *args)
 {
-	linphonec_finish(EXIT_SUCCESS);
+	linphonec_main_loop_exit();
 	return 1;
 }
 
@@ -1264,6 +1285,7 @@ linphonec_friend_call(LinphoneCore *lc, unsigned int num)
 	return 1;
 }
 
+#ifndef WIN32
 static int
 linphonec_friend_add(LinphoneCore *lc, const char *name, const char *addr)
 {
@@ -1276,6 +1298,7 @@ linphonec_friend_add(LinphoneCore *lc, const char *name, const char *addr)
 	linphone_core_add_friend(lc, newFriend);
 	return 0;
 }
+#endif
 
 static int
 linphonec_friend_delete(LinphoneCore *lc, int num)
@@ -1405,11 +1428,13 @@ static int lpc_cmd_status(LinphoneCore *lc, char *args)
 	else if (strstr(args,"hook"))
 	{
 		gstate_t call_state=linphone_core_get_state(lc,GSTATE_GROUP_CALL);
+/*
 		if (!cfg || !linphone_proxy_config_is_registered(cfg)){
 			linphonec_out("unregistered\n");
 			return 1;
 		}
-		switch(call_state){
+ */
+ 		switch(call_state){
 			case GSTATE_CALL_OUT_INVITE:
 				linphonec_out("hook=dialing\n");
 			break;
@@ -1423,6 +1448,10 @@ static int lpc_cmd_status(LinphoneCore *lc, char *args)
 			case GSTATE_CALL_IN_CONNECTED:
 				linphonec_out("hook=answered duration=%i\n" ,
 					linphone_core_get_current_call_duration(lc));
+				break;
+			case GSTATE_CALL_IN_INVITE:
+				linphonec_out("Incoming call from %s\n",linphonec_get_caller());
+				break;
 			default:
 				break;
 		}
@@ -1451,6 +1480,37 @@ static int lpc_cmd_ports(LinphoneCore *lc, char *args)
 	return 1;
 }
 
+static int lpc_cmd_speak(LinphoneCore *lc, char *args){
+#ifndef WIN32
+	char voice[64];
+	char *sentence;
+	char cl[128];
+	char *wavfile;
+	int status;
+	FILE *file;
+	memset(voice,0,sizeof(voice));
+	sscanf(args,"%s63",voice);
+	sentence=args+strlen(voice);
+	wavfile=tempnam("/tmp/","linphonec-espeak-");
+	snprintf(cl,sizeof(cl),"espeak -v %s -s 100 -w %s --stdin",voice,wavfile);
+	file=popen(cl,"w");
+	if (file==NULL){
+		ms_error("Could not open pipe to espeak !");
+		return 1;
+	}
+	fprintf(file,"%s",sentence);
+	status=pclose(file);
+	if (WEXITSTATUS(status)==0){
+		linphone_core_set_play_file(lc,wavfile);
+	}else{
+		linphonec_out("espeak command failed.");
+	}
+#else
+	linphonec_out("Sorry, this command is not implemented in windows version.");
+#endif
+	return 1;
+}
+
 /***************************************************************************
  *
  *  Command table management funx
