@@ -21,7 +21,6 @@ call.
 #include "sipomatic.h"
 #include <eXosip2/eXosip.h>
 
-
 int run_cond=1;
 
 Sipomatic sipomatic;
@@ -460,7 +459,11 @@ int main(int argc, char *argv[])
 	
 	while (run_cond){
 		sipomatic_iterate(&sipomatic);
+#ifndef WIN32
 		usleep(20000);
+#else
+		Sleep(20);
+#endif
 	}
 	
 	return(0);
