@@ -33,7 +33,8 @@ static bool_t linphone_call_matches_event(LinphoneCall *call, eXosip_event_t *ev
 
 static void linphone_call_proceeding(LinphoneCore *lc, eXosip_event_t *ev){
 	if (lc->call==NULL || (lc->call->cid!=-1 && !linphone_call_matches_event(lc->call,ev)) ) {
-		ms_warning("This call has been canceled.");
+		ms_warning("This call has been canceled: call=%p, call->cid=%i, ev->cid=%i",
+			lc->call,lc->call->cid,ev->cid);
 		eXosip_lock();
 		eXosip_call_terminate(ev->cid,ev->did);
 		eXosip_unlock();
@@ -195,6 +196,10 @@ int linphone_call_failure(LinphoneCore *lc, eXosip_event_t *ev)
 		case 415:
 			lc->vtable.display_status(lc,_("Remote user cannot support any of proposed codecs."));
 		break;
+		case 422:
+			/*ignore: eXosip_automatic_action will do the job of retrying with a greater Session-Expires*/
+			return 0;
+		break;
 		case 480:
 			tmpmsg=msg480;
 		case 486:
@@ -316,7 +321,8 @@ int linphone_inc_new_call(LinphoneCore *lc, eXosip_event_t *ev)
 		eXosip_unlock();
 		goto end;
 	}
-	lc->call=linphone_call_new_incoming(lc,from,to,ev->cid,ev->did,ev->tid);
+	lc->call=linphone_call_new_incoming(lc,from,to,ev);
+	
 	sdp=eXosip_get_sdp_info(ev->request);
 	if (sdp==NULL){
 		ms_message("No sdp body in invite, 200-ack scheme");
@@ -965,19 +971,23 @@ void linphone_registration_success(LinphoneCore *lc,eXosip_event_t *ev){
 	char *msg;
 	char *ru;
 	osip_header_t *h=NULL;
-	osip_uri_to_str(requri,&ru);
-	msg=ms_strdup_printf(_("Registration on %s successful."),ru);
-	lc->vtable.display_status(lc,msg);
-	ms_free(msg);
-	osip_free(ru);
+
 	cfg=linphone_core_get_proxy_config_from_rid(lc,ev->rid);
 	ms_return_if_fail(cfg!=NULL);
+
 	gstate_new_state(lc, GSTATE_REG_OK, NULL);
 	osip_message_get_expires(ev->request,0,&h);
 	if (h!=NULL && atoi(h->hvalue)!=0){
 		cfg->registered=TRUE;
 		linphone_proxy_config_register_again_with_updated_contact(cfg,ev->request,ev->response);
 	}else cfg->registered=FALSE;
+	
+	osip_uri_to_str(requri,&ru);
+	if (cfg->registered) msg=ms_strdup_printf(_("Registration on %s successful."),ru);
+	else msg=ms_strdup_printf(_("Unregistration on %s done."),ru);
+	lc->vtable.display_status(lc,msg);
+	ms_free(msg);
+	osip_free(ru);
 }
 
 static bool_t comes_from_local_if(osip_message_t *msg){
@@ -999,6 +1009,16 @@ static bool_t comes_from_local_if(osip_message_t *msg){
 	return FALSE;
 }
 
+static void linphone_inc_update(LinphoneCore *lc, eXosip_event_t *ev){
+	osip_message_t *msg=NULL;
+	ms_message("Processing incoming UPDATE");
+	eXosip_lock();
+	eXosip_message_build_answer(ev->tid,200,&msg);
+	if (msg!=NULL)
+		eXosip_message_send_answer(ev->tid,200,msg);
+	eXosip_unlock();
+}
+
 static void linphone_other_request(LinphoneCore *lc, eXosip_event_t *ev){
 	ms_message("in linphone_other_request");
 	if (ev->request==NULL) return;
@@ -1029,8 +1049,9 @@ static void linphone_other_request(LinphoneCore *lc, eXosip_event_t *ev){
 			}
 			
 		}else ms_warning("Ignored REFER not coming from this local loopback interface.");
-	}
-    	else {
+	}else if (strncmp(ev->request->sip_method, "UPDATE", 6) == 0){
+		linphone_inc_update(lc,ev);
+    	}else {
 		char *tmp=NULL;
 		size_t msglen=0;
 		osip_message_to_str(ev->request,&tmp,&msglen);
