@@ -37,10 +37,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #endif
 #endif
 
-#ifdef WIN32
-#define HAVE_EXOSIP_GET_VERSION 1
-#endif
-
+/*#define UNSTANDART_GSM_11K 1*/
 
 static const char *liblinphone_version=LIBLINPHONE_VERSION;
 
@@ -127,14 +124,16 @@ LinphoneCall * linphone_call_new_outgoing(struct _LinphoneCore *lc, const osip_f
 }
 
 
-LinphoneCall * linphone_call_new_incoming(LinphoneCore *lc, const char *from, const char *to, int cid, int did, int tid){
+LinphoneCall * linphone_call_new_incoming(LinphoneCore *lc, const char *from, const char *to, eXosip_event_t *ev){
 	LinphoneCall *call=ms_new0(LinphoneCall,1);
 	osip_from_t *me= linphone_core_get_primary_contact_parsed(lc);
 	osip_from_t *from_url=NULL;
+	osip_header_t *h=NULL;
+
 	call->dir=LinphoneCallIncoming;
-	call->cid=cid;
-	call->did=did;
-	call->tid=tid;
+	call->cid=ev->cid;
+	call->did=ev->did;
+	call->tid=ev->tid;
 	call->core=lc;
 	osip_from_init(&from_url);
 	osip_from_parse(from_url, from);
@@ -147,6 +146,8 @@ LinphoneCall * linphone_call_new_incoming(LinphoneCore *lc, const char *from, co
 	discover_mtu(lc,from_url->url->host);
 	osip_from_free(me);
 	osip_from_free(from_url);
+	osip_message_header_get_byname(ev->request,"Session-expires",0,&h);
+	if (h) call->supports_session_timers=TRUE;
 	return call;
 }
 
@@ -662,6 +663,10 @@ static PayloadType * linphone_mp4v_es=NULL;
 static PayloadType * linphone_h263_old=NULL;
 #endif
 
+#ifdef UNSTANDART_GSM_11K
+static PayloadType *gsm_11k=NULL;
+#endif
+
 void linphone_core_init (LinphoneCore * lc, const LinphoneCoreVTable *vtable, const char *config_path, void * userdata)
 {
 	memset (lc, 0, sizeof (LinphoneCore));
@@ -701,6 +706,12 @@ void linphone_core_init (LinphoneCore * lc, const LinphoneCoreVTable *vtable, co
 	rtp_profile_set_payload(&av_profile,102,&payload_type_h264);
 #endif
 
+#ifdef UNSTANDART_GSM_11K
+	gsm_11k=payload_type_clone(&payload_type_gsm);
+	gsm_11k->clock_rate=11025;
+	rtp_profile_set_payload(&av_profile,96,gsm_11k);
+#endif
+
 	ms_init();
 	
 	lc->config=lp_config_new(config_path);
@@ -1356,7 +1367,10 @@ int linphone_core_invite(LinphoneCore *lc, const char *url)
 		ms_warning("Could not build initial invite");
 		goto end;
 	}
-	
+	if (lp_config_get_int(lc->config,"sip","use_session_timers",0)==1){
+		osip_message_set_header(invite, "Session-expires", "200");
+		osip_message_set_supported(invite, "timer");
+	}
 	/* make sdp message */
 	
 	osip_from_init(&parsed_url2);
@@ -1742,6 +1756,9 @@ int linphone_core_accept_call(LinphoneCore *lc, const char *url)
 		ms_error("Fail to build answer for call: err=%i",err);
 		return -1;
 	}
+	if (lp_config_get_int(lc->config,"sip","use_session_timers",0)==1){
+		if (call->supports_session_timers) osip_message_set_supported(msg, "timer");
+	}
 	/*try to be best-effort in giving real local or routable contact address,
 	except when the user choosed to override the ipaddress */
 	if (linphone_core_get_firewall_policy(lc)!=LINPHONE_POLICY_USE_NAT_ADDRESS)
