@@ -150,55 +150,12 @@ typedef struct autoreplier_config
 struct _LinphoneCore;
 struct _sdp_context;
 struct _SipSetupContext;
-	
-typedef struct _StreamParams
-{
-	int initialized;
-	int line;
-	int localport;
-	int remoteport;
-	int remotertcpport;
-	int pt;
-	char *relay_session_id;
-	int natd_port;
-	char remoteaddr[LINPHONE_HOSTNAME_SIZE];
-	char natd_addr[LINPHONE_HOSTNAME_SIZE];
-} StreamParams;
+struct _LinphoneCall;
 
-typedef enum _LCState{
-	LCStateInit,
-	LCStateRinging,
-	LCStateAVRunning
-}LCState;
 
 typedef enum _LinphoneCallDir {LinphoneCallOutgoing, LinphoneCallIncoming} LinphoneCallDir;
 
 
-typedef struct _LinphoneCall
-{
-	struct _LinphoneCore *core;
-	StreamParams audio_params;
-	StreamParams video_params;
-	LinphoneCallDir dir;
-	struct _RtpProfile *profile;	/*points to the local_profile or to the remote "guessed" profile*/
-	struct _LinphoneCallLog *log;
-	int cid; /*call id */
-	int did; /*dialog id */
-	int tid; /*last transaction id*/
-	char localip[LINPHONE_IPADDR_SIZE]; /* our best guess for local ipaddress for this call */
-	struct _sdp_context *sdpctx;
-	time_t start_time; /*time at which the call was initiated*/
-	time_t media_start_time; /*time at which it was accepted, media streams established*/
-	LCState	state;
-	bool_t auth_pending;
-} LinphoneCall;
-
-LinphoneCall * linphone_call_new_outgoing(struct _LinphoneCore *lc, const osip_from_t *from, const osip_to_t *to);
-LinphoneCall * linphone_call_new_incoming(struct _LinphoneCore *lc, const char *from, const char *to, int cid, int did , int tid);
-#define linphone_call_set_state(lcall,st)	(lcall)->state=(st)
-void linphone_call_destroy(struct _LinphoneCall *obj);
-
-
 typedef enum _LinphoneCallStatus { 
 	LinphoneCallSuccess,
 	LinphoneCallAborted,
@@ -215,10 +172,7 @@ typedef struct _LinphoneCallLog{
 	
 } LinphoneCallLog;
 
-/* private: */
-LinphoneCallLog * linphone_call_log_new(LinphoneCall *call, char *local, char * remote);
-void linphone_call_log_completed(LinphoneCallLog *calllog, LinphoneCall *call);
-void linphone_call_log_destroy(LinphoneCallLog *cl);
+
 
 /*public: */
 char * linphone_call_log_to_str(LinphoneCallLog *cl);
@@ -370,6 +324,7 @@ LinphoneAuthInfo *linphone_auth_info_new(const char *username, const char *useri
 		const char *passwd, const char *ha1,const char *realm);
 void linphone_auth_info_set_passwd(LinphoneAuthInfo *info, const char *passwd);
 void linphone_auth_info_set_username(LinphoneAuthInfo *info, const char *username);
+void linphone_auth_info_set_userid(LinphoneAuthInfo *info, const char *userid);
 /* you don't need those function*/
 void linphone_auth_info_destroy(LinphoneAuthInfo *info);
 LinphoneAuthInfo * linphone_auth_info_new_from_config_file(struct _LpConfig *config, int pos);
@@ -511,7 +466,7 @@ typedef struct _LinphoneCore
 	struct _RingStream *ringstream;
 	LCCallbackObj preview_finished_cb;
 	bool_t preview_finished;
-	LinphoneCall *call;   /* the current call, in the future it will be a list of calls (conferencing)*/
+	struct _LinphoneCall *call;   /* the current call, in the future it will be a list of calls (conferencing)*/
 	int rid; /*registration id*/
 	MSList *queued_calls;	/* used by the autoreplier */
 	MSList *call_logs;
@@ -816,7 +771,7 @@ void linphone_core_destroy(LinphoneCore *lc);
 /*internal use only */
 #define linphone_core_lock(lc)	ms_mutex_lock(&(lc)->lock)
 #define linphone_core_unlock(lc)	ms_mutex_unlock((&lc)->lock)
-void linphone_core_start_media_streams(LinphoneCore *lc, LinphoneCall *call);
+void linphone_core_start_media_streams(LinphoneCore *lc, struct _LinphoneCall *call);
 void linphone_core_stop_media_streams(LinphoneCore *lc);
 const char * linphone_core_get_identity(LinphoneCore *lc);
 const char * linphone_core_get_route(LinphoneCore *lc);
