@@ -42,6 +42,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 GdkPixbuf * create_pixbuf(const gchar *filename);
 GdkPixbufAnimation *create_pixbuf_animation(const gchar *filename);
 void add_pixmap_directory(const gchar *directory);
+GtkWidget*create_pixmap(const gchar     *filename);
 GtkWidget *linphone_gtk_create_window(const char *window_name);
 GtkWidget *linphone_gtk_get_widget(GtkWidget *window, const char *name);
 LinphoneCore *linphone_gtk_get_core(void);
@@ -64,6 +65,8 @@ void linphone_gtk_destroy_log_window(void);
 gboolean linphone_gtk_check_logs();
 const gchar *linphone_gtk_get_ui_config(const char *key, const char *def);
 int linphone_gtk_get_ui_config_int(const char *key, int def);
+void linphone_gtk_set_ui_config_int(const char *key , int val);
+
 void linphone_gtk_open_browser(const char *url);
 void linphone_gtk_check_for_new_version(void);
 const char *linphone_gtk_get_lang(const char *config_file);
@@ -77,10 +80,14 @@ gchar *linphone_gtk_get_display_name(const char *sip_uri);
 void linphone_gtk_show_directory_search(void);
 
 /*functions controlling the different views*/
+gboolean linphone_gtk_use_in_call_view();
 void linphone_gtk_show_in_call_view(void);
 void linphone_gtk_show_idle_view(void);
 void linphone_gtk_in_call_view_set_calling(const char *uri);
 void linphone_gtk_in_call_view_set_in_call(void);
 void linphone_gtk_in_call_view_update_duration(int duration);
 void linphone_gtk_in_call_view_terminate(const char *error_msg);
+void linphone_gtk_enable_mute_button(GtkToggleButton *button, gboolean sensitive);
+
 void linphone_gtk_show_login_frame(LinphoneProxyConfig *cfg);
+
