@@ -135,6 +135,7 @@ static GOptionEntry linphone_options[]={
 
 static char _config_file[1024];
 
+
 const char *linphone_gtk_get_config_file(){
 	/*try accessing a local file first if exists*/
 	if (access(CONFIG_FILE,F_OK)==0){
@@ -172,7 +173,7 @@ GtkWidget *linphone_gtk_get_main_window(){
 	return the_ui;
 }
 
-static void parse_item(const char *item, const char *window_name, GtkWidget *w){
+static void parse_item(const char *item, const char *window_name, GtkWidget *w,  gboolean show){
 	char tmp[64];
 	char *dot;
 	strcpy(tmp,item);
@@ -182,12 +183,15 @@ static void parse_item(const char *item, const char *window_name, GtkWidget *w){
 		dot++;
 		if (strcmp(window_name,tmp)==0){
 			GtkWidget *wd=linphone_gtk_get_widget(w,dot);
-			if (wd) gtk_widget_hide(wd);
+			if (wd) {
+				if (!show) gtk_widget_hide(wd);
+				else gtk_widget_show(wd);
+			}
 		}
 	}
 }
 
-static void parse_hiddens(const char *hiddens, const char *window_name, GtkWidget *w){
+static void parse_widgets(const char *hiddens, const char *window_name, GtkWidget *w, gboolean show){
 	char item[64];
 	const char *i;
 	const char *b;
@@ -198,30 +202,33 @@ static void parse_hiddens(const char *hiddens, const char *window_name, GtkWidge
 			strncpy(item,b,len);
 			item[len]='\0';
 			b=i+1;
-			parse_item(item,window_name,w);
+			parse_item(item,window_name,w,show);
 		}
 	}
 	len=MIN(i-b,sizeof(item)-1);
 	if (len>0){
 		strncpy(item,b,len);
 		item[len]='\0';
-		parse_item(item,window_name,w);
+		parse_item(item,window_name,w,show);
 	}
 }
 
 static void linphone_gtk_configure_window(GtkWidget *w, const char *window_name){
-	static const char *icon_path=0;
-	static const char *hiddens=0;
+	static const char *icon_path=NULL;
+	static const char *hiddens=NULL;
+	static const char *shown=NULL;
 	static bool_t config_loaded=FALSE;
 	if (linphone_gtk_get_core()==NULL) return;
 	if (config_loaded==FALSE){
 		hiddens=linphone_gtk_get_ui_config("hidden_widgets",NULL);
+		shown=linphone_gtk_get_ui_config("shown_widgets",NULL);
 		icon_path=linphone_gtk_get_ui_config("icon",NULL);
 		config_loaded=TRUE;
 	}
-	if (hiddens){
-		parse_hiddens(hiddens,window_name,w);
-	}
+	if (hiddens)
+		parse_widgets(hiddens,window_name,w,FALSE);
+	if (shown)
+		parse_widgets(shown,window_name,w,TRUE);
 	if (icon_path) {
 		GdkPixbuf *pbuf=create_pixbuf(icon_path);
 		gtk_window_set_icon(GTK_WINDOW(w),pbuf);
@@ -510,13 +517,19 @@ static void completion_add_text(GtkEntry *entry, const char *text){
 
 void linphone_gtk_call_terminated(const char *error){
 	GtkWidget *mw=linphone_gtk_get_main_window();
+	GtkWidget *icw;
 	gtk_widget_set_sensitive(linphone_gtk_get_widget(mw,"terminate_call"),FALSE);
 	gtk_widget_set_sensitive(linphone_gtk_get_widget(mw,"start_call"),TRUE);
 	gtk_widget_hide_all(linphone_gtk_get_widget(mw,"go_to_call_view_box"));
-	linphone_gtk_in_call_view_terminate(error);
+	linphone_gtk_enable_mute_button(GTK_TOGGLE_BUTTON(linphone_gtk_get_widget(mw,"main_mute")),FALSE);
+	if (linphone_gtk_use_in_call_view())
+		linphone_gtk_in_call_view_terminate(error);
 	update_video_title();
-	g_object_set_data(G_OBJECT(mw),"incoming_call",NULL);
-	
+	icw=GTK_WIDGET(g_object_get_data(G_OBJECT(mw),"incoming_call"));
+	if (icw!=NULL){
+		g_object_set_data(G_OBJECT(mw),"incoming_call",NULL);
+		gtk_widget_destroy(icw);
+	}
 }
 
 static gboolean in_call_timer(){
@@ -533,7 +546,8 @@ static void linphone_gtk_call_started(GtkWidget *mw){
 	gtk_widget_set_sensitive(linphone_gtk_get_widget(mw,"terminate_call"),TRUE);
 	gtk_widget_show_all(linphone_gtk_get_widget(mw,"go_to_call_view_box"));
 	update_video_title();
-	g_timeout_add(250,(GSourceFunc)in_call_timer,NULL);
+	if (linphone_gtk_use_in_call_view())
+		g_timeout_add(250,(GSourceFunc)in_call_timer,NULL);
 }
 
 static gboolean linphone_gtk_start_call_do(GtkWidget *uri_bar){
@@ -545,9 +559,32 @@ static gboolean linphone_gtk_start_call_do(GtkWidget *uri_bar){
 	return FALSE;
 }
 
+static void _linphone_gtk_accept_call(){
+	LinphoneCore *lc=linphone_gtk_get_core();
+	GtkWidget *mw=linphone_gtk_get_main_window();
+	GtkWidget *icw=GTK_WIDGET(g_object_get_data(G_OBJECT(mw),"incoming_call"));
+	if (icw!=NULL){
+		g_object_set_data(G_OBJECT(mw),"incoming_call",NULL);
+		gtk_widget_destroy(icw);
+	}
+
+	linphone_core_accept_call(lc,NULL);
+	linphone_gtk_call_started(linphone_gtk_get_main_window());
+	if (linphone_gtk_use_in_call_view()){
+		linphone_gtk_in_call_view_set_in_call();
+		linphone_gtk_show_in_call_view();
+	}
+	linphone_gtk_enable_mute_button(
+		GTK_TOGGLE_BUTTON(linphone_gtk_get_widget(linphone_gtk_get_main_window(),"main_mute"))
+		,TRUE);
+}
+
 void linphone_gtk_start_call(GtkWidget *w){
 	LinphoneCore *lc=linphone_gtk_get_core();
-	if (linphone_core_inc_invite_pending(lc) || linphone_core_in_call(lc)) {
+	if (linphone_core_inc_invite_pending(lc)){
+		/*accept the call*/
+		_linphone_gtk_accept_call();
+	}else if (linphone_core_in_call(lc)) {
 		/*already in call */
 	}else{
 		/*change into in-call mode, then do the work later as it might block a bit */
@@ -555,8 +592,10 @@ void linphone_gtk_start_call(GtkWidget *w){
 		GtkWidget *uri_bar=linphone_gtk_get_widget(mw,"uribar");
 		const char *entered=gtk_entry_get_text(GTK_ENTRY(uri_bar));
 		linphone_gtk_call_started(mw);
-		linphone_gtk_in_call_view_set_calling(entered);
-		linphone_gtk_show_in_call_view();
+		if (linphone_gtk_use_in_call_view()){
+			linphone_gtk_in_call_view_set_calling(entered);
+			linphone_gtk_show_in_call_view();
+		}
 		g_timeout_add(100,(GSourceFunc)linphone_gtk_start_call_do,uri_bar);
 	}
 }
@@ -579,13 +618,7 @@ void linphone_gtk_decline_call(GtkWidget *button){
 }
 
 void linphone_gtk_accept_call(GtkWidget *button){
-	LinphoneCore *lc=linphone_gtk_get_core();
-	linphone_core_accept_call(lc,NULL);
-	g_object_set_data(G_OBJECT(linphone_gtk_get_main_window()),"incoming_call",NULL);
-	gtk_widget_destroy(gtk_widget_get_toplevel(button));
-	linphone_gtk_call_started(linphone_gtk_get_main_window());
-	linphone_gtk_in_call_view_set_in_call();
-	linphone_gtk_show_in_call_view();
+	_linphone_gtk_accept_call();
 }
 
 static gboolean linphone_gtk_auto_answer(GtkWidget *incall_window){
@@ -655,10 +688,7 @@ static void linphone_gtk_inv_recv(LinphoneCore *lc, const char *from){
 }
 
 static void linphone_gtk_bye_recv(LinphoneCore *lc, const char *from){
-	GtkWidget *icw=GTK_WIDGET(g_object_get_data(G_OBJECT(linphone_gtk_get_main_window()),"incoming_call"));
-	if (icw!=NULL){
-		gtk_widget_destroy(icw);
-	}
+	
 }
 
 static void linphone_gtk_notify_recv(LinphoneCore *lc, LinphoneFriend * fid, const char *url, const char *status, const char *img){
@@ -736,8 +766,8 @@ void linphone_gtk_password_ok(GtkWidget *w){
 	g_object_weak_unref(G_OBJECT(window),(GWeakNotify)linphone_auth_info_destroy,info);
 	entry=linphone_gtk_get_widget(window,"password_entry");
 	linphone_auth_info_set_passwd(info,gtk_entry_get_text(GTK_ENTRY(entry)));
-	linphone_auth_info_set_username(info,
-		gtk_entry_get_text(GTK_ENTRY(linphone_gtk_get_widget(window,"username_entry"))));
+	linphone_auth_info_set_userid(info,
+		gtk_entry_get_text(GTK_ENTRY(linphone_gtk_get_widget(window,"userid_entry"))));
 	linphone_core_add_auth_info(linphone_gtk_get_core(),info);
 	gtk_widget_destroy(window);
 }
@@ -747,10 +777,11 @@ static void linphone_gtk_auth_info_requested(LinphoneCore *lc, const char *realm
 	GtkWidget *label=linphone_gtk_get_widget(w,"message");
 	LinphoneAuthInfo *info;
 	gchar *msg;
-	msg=g_strdup_printf(_("Please enter your password for domain %s:"),realm);
-	gtk_label_set_text(GTK_LABEL(label),msg);
+	msg=g_strdup_printf(_("Please enter your password for username <i>%s</i>\n at domain <i>%s</i>:"),
+		username,realm);
+	gtk_label_set_markup(GTK_LABEL(label),msg);
 	g_free(msg);
-	gtk_entry_set_text(GTK_ENTRY(linphone_gtk_get_widget(w,"username_entry")),username);
+	gtk_entry_set_text(GTK_ENTRY(linphone_gtk_get_widget(w,"userid_entry")),username);
 	info=linphone_auth_info_new(username, NULL, NULL, NULL,realm);
 	g_object_set_data(G_OBJECT(w),"auth_info",info);
 	g_object_weak_ref(G_OBJECT(w),(GWeakNotify)linphone_auth_info_destroy,info);
@@ -793,7 +824,11 @@ static void linphone_gtk_general_state(LinphoneCore *lc, LinphoneGeneralState *g
 	switch(gstate->new_state){
 		case GSTATE_CALL_OUT_CONNECTED:
 		case GSTATE_CALL_IN_CONNECTED:
-			linphone_gtk_in_call_view_set_in_call();
+			if (linphone_gtk_use_in_call_view())
+				linphone_gtk_in_call_view_set_in_call();
+			linphone_gtk_enable_mute_button(
+				GTK_TOGGLE_BUTTON(linphone_gtk_get_widget(linphone_gtk_get_main_window(),"main_mute")),
+			TRUE);
 		break;
 		case GSTATE_CALL_ERROR:
 			linphone_gtk_call_terminated(gstate->message);
@@ -836,7 +871,7 @@ static GtkWidget *create_icon_menu(){
 	const gchar *homesite;
 	
 	homesite=linphone_gtk_get_ui_config("home","http://www.linphone.org");
-	menu_item=gtk_image_menu_item_new_with_label(homesite);
+	menu_item=gtk_image_menu_item_new_with_label(_("Website link"));
 	tmp=g_strdup(homesite);
 	g_object_set_data(G_OBJECT(menu_item),"home",tmp);
 	g_object_weak_ref(G_OBJECT(menu_item),(GWeakNotify)g_free,tmp);
@@ -1009,6 +1044,10 @@ static void linphone_gtk_init_main_window(){
 	linphone_gtk_show_friends();
 	linphone_gtk_connect_digits();
 	linphone_gtk_check_menu_items();
+	linphone_gtk_enable_mute_button(GTK_TOGGLE_BUTTON(linphone_gtk_get_widget(linphone_gtk_get_main_window(),
+					"main_mute")),FALSE);
+	linphone_gtk_enable_mute_button(GTK_TOGGLE_BUTTON(linphone_gtk_get_widget(linphone_gtk_get_main_window(),
+					"incall_mute")),FALSE);
 	if (linphone_core_in_call(linphone_gtk_get_core())) linphone_gtk_call_started(
 		linphone_gtk_get_main_window());/*hide the call button, show terminate button*/
 }
