@@ -48,11 +48,19 @@ struct _AudioStream
 	MSFilter *dtmfgen;
 	MSFilter *ec;/*echo canceler*/
 	MSFilter *volsend,*volrecv; /*MSVolumes*/
+	MSFilter *resampler;
+	MSFilter *equalizer;
 	uint64_t last_packet_count;
 	time_t last_packet_time;
 	EchoLimiterType el_type; /*use echo limiter: two MSVolume, measured input level controlling local output level*/
+	int ec_tail_len; /*milliseconds*/
+	int ec_delay;	/*milliseconds*/
+	int ec_framesize; /* number of fft points */
 	bool_t play_dtmfs;
 	bool_t use_gc;
+	bool_t use_agc;
+	bool_t eq_active;
+	bool_t use_ng;/*noise gate*/
 };
 
 #ifdef __cplusplus
@@ -105,8 +113,22 @@ void audio_stream_enable_echo_limiter(AudioStream *stream, EchoLimiterType type)
 /*enable gain control, to be done before start() */
 void audio_stream_enable_gain_control(AudioStream *stream, bool_t val);
 
+/*enable automatic gain control, to be done before start() */
+void audio_stream_enable_automatic_gain_control(AudioStream *stream, bool_t val);
+
+/*to be done before start */
+void audio_stream_set_echo_canceler_params(AudioStream *st, int tail_len_ms, int delay_ms, int framesize);
+
 void audio_stream_set_mic_gain(AudioStream *stream, float gain);
 
+/*enable noise gate, must be done before start()*/
+void audio_stream_enable_noise_gate(AudioStream *stream, bool_t val);
+
+/*enable parametric equalizer in the stream that goes to the speaker*/
+void audio_stream_enable_equalizer(AudioStream *stream, bool_t enabled);
+
+void audio_stream_equalizer_set_gain(AudioStream *stream, int frequency, float gain, int freq_width);
+
 /* stop the audio streaming thread and free everything*/
 void audio_stream_stop (AudioStream * stream);
 
