@@ -31,10 +31,19 @@ typedef struct Rfc3984Context{
 	MSQueue q;
 	mblk_t *m;
 	int maxsz;
+	uint32_t last_ts;
+	uint8_t mode;
+	bool_t stap_a_allowed;
+	uint8_t reserved;
 } Rfc3984Context;
 
 void rfc3984_init(Rfc3984Context *ctx);
 
+void rfc3984_set_mode(Rfc3984Context *ctx, int mode);
+
+/* some stupid phones don't decode STAP-A packets ...*/
+void rfc3984_enable_stap_a(Rfc3984Context *ctx, bool_t yesno);
+
 /*process NALUs and pack them into rtp payloads */
 void rfc3984_pack(Rfc3984Context *ctx, MSQueue *naluq, MSQueue *rtpq, uint32_t ts);
 
