@@ -287,6 +287,8 @@ static int alsa_can_read(snd_pcm_t *dev)
 	int err;
 
 	avail = snd_pcm_avail_update(dev);
+	/* A buggy driver does not return an error while being in Xrun */
+	if (avail >= 0 && snd_pcm_state(dev) == SND_PCM_STATE_XRUN) avail=-EPIPE;
 	if (avail < 0) {
 		ms_error("snd_pcm_avail_update: %s", snd_strerror(avail));	// most probably -EPIPE
 		/* overrun occured, snd_pcm_state() would return SND_PCM_STATE_XRUN
@@ -594,6 +596,8 @@ MSSndCardDesc alsa_card_desc={
 	.set_level=alsa_card_set_level,
 	.get_level=alsa_card_get_level,
 	.set_capture=alsa_card_set_source,
+	.set_control=NULL,
+	.get_control=NULL,
 	.create_reader=alsa_card_create_reader,
 	.create_writer=alsa_card_create_writer,
 	.uninit=alsa_card_uninit,
@@ -665,6 +669,16 @@ static MSSndCard * alsa_card_new(int id)
 		obj->name=pos1;
 		ad->pcmdev=ms_strdup_printf("default:%i",id);
 		ad->mixdev=ms_strdup_printf("default:%i",id);
+		{
+			snd_mixer_t *mixer;
+			mixer = alsa_mixer_open(ad->mixdev);
+			if (mixer==NULL) {
+				ms_free(ad->mixdev);
+				ad->mixdev=ms_strdup_printf("hw:%i",id);
+			} else {
+				alsa_mixer_close(mixer);
+			}
+		}
 	}
 	/*check card capabilities: */
 	obj->capabilities=get_card_capabilities(ad->pcmdev);
@@ -878,6 +892,12 @@ void alsa_read_process(MSFilter *obj){
 }
 #endif
 
+static int alsa_read_get_sample_rate(MSFilter *obj, void *param){
+	AlsaReadData *ad=(AlsaReadData*)obj->data;
+	*((int*)param)=ad->rate;
+	return 0;
+}
+
 static int alsa_read_set_sample_rate(MSFilter *obj, void *param){
 	AlsaReadData *ad=(AlsaReadData*)obj->data;
 	ad->rate=*((int*)param);
@@ -891,8 +911,9 @@ static int alsa_read_set_nchannels(MSFilter *obj, void *param){
 }
 
 MSFilterMethod alsa_read_methods[]={
+	{MS_FILTER_GET_SAMPLE_RATE,	alsa_read_get_sample_rate},
 	{MS_FILTER_SET_SAMPLE_RATE, alsa_read_set_sample_rate},
-	{MS_FILTER_SET_SAMPLE_RATE, alsa_read_set_nchannels},
+	{MS_FILTER_SET_NCHANNELS, alsa_read_set_nchannels},
 	{0,NULL}
 };
 
@@ -944,6 +965,12 @@ void alsa_write_uninit(MSFilter *obj){
 	ms_free(ad);
 }
 
+static int alsa_write_get_sample_rate(MSFilter *obj, void *data){
+	AlsaWriteData *ad=(AlsaWriteData*)obj->data;
+	*((int*)data)=ad->rate;
+	return 0;
+}
+
 int alsa_write_set_sample_rate(MSFilter *obj, void *data){
 	int *rate=(int*)data;
 	AlsaWriteData *ad=(AlsaWriteData*)obj->data;
@@ -988,6 +1015,7 @@ void alsa_write_process(MSFilter *obj){
 }
 
 MSFilterMethod alsa_write_methods[]={
+	{MS_FILTER_GET_SAMPLE_RATE,	alsa_write_get_sample_rate},
 	{MS_FILTER_SET_SAMPLE_RATE, alsa_write_set_sample_rate},
 	{MS_FILTER_SET_NCHANNELS, alsa_write_set_nchannels},
 	{0,NULL}
