@@ -157,13 +157,13 @@ int ms_filter_call_method(MSFilter *f, unsigned int id, void *arg){
 	int i;
 	unsigned int magic=MS_FILTER_METHOD_GET_FID(id);
 	if (magic!=MS_FILTER_BASE_ID && magic!=f->desc->id) {
-		ms_fatal("Bad method definition in filter %s",f->desc->name);
+		ms_fatal("Method type checking failed when calling %u on filter %s",id,f->desc->name);
 		return -1;
 	}
 	for(i=0;methods!=NULL && methods[i].method!=NULL; i++){
 		unsigned int mm=MS_FILTER_METHOD_GET_FID(methods[i].id);
 		if (mm!=f->desc->id && mm!=MS_FILTER_BASE_ID) {
-			ms_fatal("MSFilter method mismatch: bad call.");
+			ms_fatal("Bad method definition on filter %s. fid=%u , mm=%u",f->desc->name,f->desc->id,mm);
 			return -1;
 		}
 		if (methods[i].id==id){
@@ -199,7 +199,6 @@ void ms_filter_process(MSFilter *f){
 }
 
 void ms_filter_preprocess(MSFilter *f, struct _MSTicker *t){
-	f->seen=FALSE;
 	f->last_tick=0;
 	f->ticker=t;
 	if (f->desc->preprocess!=NULL)
@@ -209,7 +208,6 @@ void ms_filter_preprocess(MSFilter *f, struct _MSTicker *t){
 void ms_filter_postprocess(MSFilter *f){
 	if (f->desc->postprocess!=NULL)
 		f->desc->postprocess(f);
-	f->seen=FALSE;
 	f->ticker=NULL;
 }
 
@@ -232,6 +230,47 @@ void ms_filter_notify_no_arg(MSFilter *f, unsigned int id){
 		f->notify(f->notify_ud,id,NULL);
 }
 
+
+static void find_filters(MSList **filters, MSFilter *f ){
+	int i,found;
+	MSQueue *link;
+	if (f==NULL) ms_fatal("Bad graph.");
+	/*ms_message("seeing %s, seen=%i",f->desc->name,f->seen);*/
+	if (f->seen){
+		return;
+	}
+	f->seen=TRUE;
+	*filters=ms_list_append(*filters,f);
+	/* go upstream */
+	for(i=0;i<f->desc->ninputs;i++){
+		link=f->inputs[i];
+		if (link!=NULL) find_filters(filters,link->prev.filter);
+	}
+	/* go downstream */
+	for(i=0,found=0;i<f->desc->noutputs;i++){
+		link=f->outputs[i];
+		if (link!=NULL) {
+			found++;
+			find_filters(filters,link->next.filter);
+		}
+	}
+	if (f->desc->noutputs>=1 && found==0){
+		ms_fatal("Bad graph: filter %s has %i outputs, none is connected.",f->desc->name,f->desc->noutputs);
+	}
+}
+
+MSList * ms_filter_find_neighbours(MSFilter *me){
+	MSList *l=NULL;
+	MSList *it;
+	find_filters(&l,me);
+	/*reset seen boolean for further lookups to succeed !*/
+	for(it=l;it!=NULL;it=it->next){
+		MSFilter *f=(MSFilter*)it->data;
+		f->seen=FALSE;
+	}
+	return l;
+}
+
 void ms_connection_helper_start(MSConnectionHelper *h){
 	h->last.filter=0;
 	h->last.pin=-1;
