@@ -539,7 +539,8 @@ static int v4l_configure(V4lState *s)
 		return -1;
 	}
 
-	ms_message("Found %s device. (maxsize=%ix%i)",cap.name, cap.maxwidth, cap.maxheight);
+	ms_message("Found %s device. (maxsize=%ix%i, minsize=%ix%i)",cap.name, cap.maxwidth, cap.maxheight,
+			cap.minwidth, cap.minheight);
 	for (i=0;i<cap.channels;i++)
 	{
 		chan.channel=i;
@@ -1005,7 +1006,7 @@ static int v4l_set_devfile(MSFilter *f, void *arg){
 MSFilterDesc ms_v4l_desc={
 	.id=MS_V4L_ID,
 	.name="MSV4l",
-	.text="A video4linux compatible source filter to stream pictures.",
+	.text=N_("A video4linux compatible source filter to stream pictures."),
 	.ninputs=0,
 	.noutputs=1,
 	.category=MS_FILTER_OTHER,
