@@ -201,7 +201,7 @@ static void prepare(EncState *s){
 	avcodec_get_context_defaults(c);
 	/* put codec parameters */
 	c->bit_rate=(float)s->maxbr*0.7;
-	c->bit_rate_tolerance=(float)c->bit_rate/(s->fps-1);
+	c->bit_rate_tolerance=s->fps!=1?(float)c->bit_rate/(s->fps-1):c->bit_rate;
 
 	if (s->codec!=CODEC_ID_SNOW && s->maxbr<256000){
 		/*snow does not like 1st pass rate control*/
@@ -577,7 +577,7 @@ static int enc_set_br(MSFilter *f, void *arg){
 		ms_filter_lock(f);
 		enc_postprocess(f);
 		enc_preprocess(f);
-		ms_filter_lock(f);
+		ms_filter_unlock(f);
 	}
 	return 0;
 }
@@ -746,9 +746,3 @@ void __register_ffmpeg_encoders_if_possible(void){
 		ms_filter_register(&ms_snow_enc_desc);
 }
 
-/*
-MS_FILTER_DESC_EXPORT(ms_mpeg4_enc_desc)
-MS_FILTER_DESC_EXPORT(ms_h263_enc_desc)
-MS_FILTER_DESC_EXPORT(ms_h263_old_enc_desc)
-MS_FILTER_DESC_EXPORT(ms_snow_enc_desc)
-*/
