@@ -21,7 +21,11 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "mediastreamer-config.h"
 #endif
 
+#include <math.h>
+
 #include "mediastreamer2/mediastream.h"
+#include "mediastreamer2/msequalizer.h"
+#include "mediastreamer2/msvolume.h"
 #ifdef VIDEO_ENABLED
 #include "mediastreamer2/msv4l.h"
 #endif
@@ -37,6 +41,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 static int cond=1;
 
+static const char * capture_card=NULL;
+static float ng_threshold=-1;
+static bool_t use_ng=FALSE;
+
 static void stop_handler(int signum)
 {
 	cond--;
@@ -122,8 +130,13 @@ const char *usage="mediastream --local <port> --remote <ip:port> --payload <payl
 								"[ --jitter <miliseconds>]\n"
 								"[ --width <pixels>]\n"
 								"[ --height <pixels> ]\n"
-								"[ --bitrate <bits per seconds>]\n";
-static void run_media_streams(int localport, const char *remote_ip, int remoteport, int payload, const char *fmtp, int jitter, bool_t ec, int bitrate, MSVideoSize vs);
+								"[ --bitrate <bits per seconds>]\n"
+								"[ --ec (enable echo canceller)]\n"
+								"[ --agc (enable automatic gain control)]\n"
+								"[ --ng (enable noise gate)]\n"
+								"[ --ng-threshold <(float) [0-1]> (noise gate threshold)]\n"
+								"[ --capture-card <index>] \n";
+static void run_media_streams(int localport, const char *remote_ip, int remoteport, int payload, const char *fmtp, int jitter, bool_t ec, int bitrate, MSVideoSize vs, bool_t agc, bool_t eq);
 
 
 int main(int argc, char * argv[])
@@ -136,6 +149,8 @@ int main(int argc, char * argv[])
 	int bitrate=0;
 	MSVideoSize vs;
 	bool_t ec=FALSE;
+	bool_t agc=FALSE;
+	bool_t eq=FALSE;
 	/*create the rtp session */
 	ortp_init();
 	ortp_set_log_level_mask(ORTP_MESSAGE|ORTP_WARNING|ORTP_ERROR|ORTP_FATAL);
@@ -186,16 +201,28 @@ int main(int argc, char * argv[])
 		}else if (strcmp(argv[i],"--height")==0){
 			i++;
 			vs.height=atoi(argv[i]);
+		}else if (strcmp(argv[i],"--capture-card")==0){
+			i++;
+			capture_card=argv[i];
 		}else if (strcmp(argv[i],"--ec")==0){
 			ec=TRUE;
+		}else if (strcmp(argv[i],"--agc")==0){
+			agc=TRUE;
+		}else if (strcmp(argv[i],"--eq")==0){
+			eq=TRUE;
+		}else if (strcmp(argv[i],"--ng")==0){
+			use_ng=1;
+		}else if (strcmp(argv[i],"--ng-threshold")==0){
+			i++;
+			ng_threshold=atof(argv[i]);
 		}
 	}
 
-	run_media_streams(localport,ip,remoteport,payload,fmtp,jitter,ec,bitrate,vs);
+	run_media_streams(localport,ip,remoteport,payload,fmtp,jitter,ec,bitrate,vs, agc,eq);
 	return 0;
 }
 
-void run_media_streams(int localport,  const char *remote_ip, int remoteport, int payload, const char *fmtp, int jitter, bool_t ec, int bitrate, MSVideoSize vs)
+void run_media_streams(int localport,  const char *remote_ip, int remoteport, int payload, const char *fmtp, int jitter, bool_t ec, int bitrate, MSVideoSize vs, bool_t agc, bool_t eq)
 {
 	AudioStream *audio=NULL;
 #ifdef VIDEO_ENABLED
@@ -218,10 +245,27 @@ void run_media_streams(int localport,  const char *remote_ip, int remoteport, in
 
 	if (pt->type!=PAYLOAD_VIDEO){
 		printf("Starting audio stream.\n");
-		audio=audio_stream_start(profile,localport,remote_ip,remoteport,payload,jitter, ec);
-		if (audio) session=audio->session;
+		MSSndCardManager *manager=ms_snd_card_manager_get();
+		MSSndCard *capt= capture_card==NULL ? ms_snd_card_manager_get_default_capture_card(manager) :
+				ms_snd_card_manager_get_card(manager,capture_card);
+		audio=audio_stream_new(localport,ms_is_ipv6(remote_ip));
+		audio_stream_enable_automatic_gain_control(audio,agc);
+		audio_stream_enable_noise_gate(audio,use_ng);
+		audio_stream_start_now(audio,profile,remote_ip,remoteport,remoteport+1,payload,jitter,
+			ms_snd_card_manager_get_default_playback_card(manager),
+			capt,
+			 ec);
+		if (audio) {
+			if (use_ng && ng_threshold!=-1)
+				ms_filter_call_method(audio->volsend,MS_VOLUME_SET_NOISE_GATE_THRESHOLD,&ng_threshold);
+			session=audio->session;
+		}
 	}else{
 #ifdef VIDEO_ENABLED
+		if (eq){
+			ms_fatal("Cannot put an audio equalizer in a video stream !");
+			exit(-1);
+		}
 		printf("Starting video stream.\n");
 		video=video_stream_new(localport, ms_is_ipv6(remote_ip));
 		video_stream_set_sent_video_size(video,vs);
@@ -236,34 +280,68 @@ void run_media_streams(int localport,  const char *remote_ip, int remoteport, in
 		printf("Error: video support not compiled.\n");
 #endif
 	}
-	rtp_session_register_event_queue(session,q);
-	while(cond)
-	{
-		int n;
-        	for(n=0;n<100;++n){
-#ifdef WIN32
-			MSG msg;
-			Sleep(10);
-			while (PeekMessage(&msg, NULL, 0, 0,1)){
-        			TranslateMessage(&msg);
-        			DispatchMessage(&msg);
+	if (!eq){
+		rtp_session_register_event_queue(session,q);
+		while(cond)
+		{
+			int n;
+			for(n=0;n<100;++n){
+	#ifdef WIN32
+				MSG msg;
+				Sleep(10);
+				while (PeekMessage(&msg, NULL, 0, 0,1)){
+					TranslateMessage(&msg);
+					DispatchMessage(&msg);
+				}
+	#else
+				struct timespec ts;
+				ts.tv_sec=0;
+				ts.tv_nsec=10000000;
+				nanosleep(&ts,NULL);
+	#endif
+	#if defined(VIDEO_ENABLED)
+				if (video) video_stream_iterate(video);
+	#endif
+			}
+			ortp_global_stats_display();
+			if (session){
+				printf("Bandwidth usage: download=%f kbits/sec, upload=%f kbits/sec\n",
+					rtp_session_compute_recv_bandwidth(session)*1e-3,
+					rtp_session_compute_send_bandwidth(session)*1e-3);
+				parse_events(q);
 			}
-#else
-			struct timespec ts;
-			ts.tv_sec=0;
-			ts.tv_nsec=10000000;
-			nanosleep(&ts,NULL);
-#endif
-#if defined(VIDEO_ENABLED)
-			if (video) video_stream_iterate(video);
-#endif
 		}
-		ortp_global_stats_display();
-		if (session){
-			printf("Bandwidth usage: download=%f kbits/sec, upload=%f kbits/sec\n",
-				rtp_session_compute_recv_bandwidth(session)*1e-3,
-				rtp_session_compute_send_bandwidth(session)*1e-3);
-			parse_events(q);
+	}else{/*read from stdin equalizer commands */
+		char commands[128];
+		commands[127]='\0';
+		printf("Please enter equalizer requests, such as 'eq active 1', 'eq active 0', 'eq 1200 0.1'\n");
+		while(fgets(commands,sizeof(commands)-1,stdin)!=NULL){
+			int active,freq,freq_width;
+			float gain;
+			if (sscanf(commands,"eq active %i",&active)==1){
+				audio_stream_enable_equalizer(audio,active);
+				printf("OK\n");
+			}else if (sscanf(commands,"eq %i:%f:%i",&freq,&gain,&freq_width)==3){
+				audio_stream_equalizer_set_gain(audio,freq,gain,freq_width);
+				printf("OK\n");
+			}else if (sscanf(commands,"eq %i:%f",&freq,&gain)==2){
+				audio_stream_equalizer_set_gain(audio,freq,gain,0);
+				printf("OK\n");
+			}else if (strstr(commands,"dump")){
+				int n=0,i;
+				float *t;
+				ms_filter_call_method(audio->equalizer,MS_EQUALIZER_GET_NUM_FREQUENCIES,&n);
+				t=(float*)alloca(sizeof(float)*n);
+				ms_filter_call_method(audio->equalizer,MS_EQUALIZER_DUMP_STATE,t);
+				for(i=0;i<n;++i){
+					if (fabs(t[i]-1)>0.01){
+						printf("%i:%f:0 ",(i*pt->clock_rate)/(2*n),t[i]);
+					}
+				}
+				printf("\nOK\n");
+			}else if (strstr(commands,"quit")){
+				break;
+			}else printf("Cannot understand this.\n");
 		}
 	}
 	
