@@ -110,26 +110,24 @@ int session_set_select(SessionSet *recvs, SessionSet *sends, SessionSet *errors)
 		if (recvs!=NULL){
 			session_set_init(&temp);
 			bits=session_set_and(&sched->r_sessions,sched->all_max,recvs,&temp);
-			if (bits>0){
-				ret+=bits;
-				/* copy the result set in the given user set */
-				session_set_copy(recvs,&temp);
-			}
+			ret+=bits;
+			/* copy the result set in the given user set (might be empty) */
+			if (ret>0) session_set_copy(recvs,&temp);
 		}
 		if (sends!=NULL){
 			session_set_init(&temp);
 			bits=session_set_and(&sched->w_sessions,sched->all_max,sends,&temp);
-			if (bits>0){
-				ret+=bits;
-				/* copy the result set in the given user set */
+			ret+=bits;
+			if (ret>0){
+				/* copy the result set in the given user set (might be empty)*/
 				session_set_copy(sends,&temp);
 			}
 		}
 		if (errors!=NULL){
 			session_set_init(&temp);
 			bits=session_set_and(&sched->e_sessions,sched->all_max,errors,&temp);
-			if (bits>0){
-				ret+=bits;
+			ret+=bits;
+			if (ret>0){
 				/* copy the result set in the given user set */
 				session_set_copy(errors,&temp);
 			}
